package Getopt::EX::i18n::iso639;
use v5.14;
use warnings;
use Exporter 'import';

our @EXPORT_OK = qw(%iso639);

##
## This data is generated by ISO::639 module.
##

our %iso639 = (
    af => "Afrikaans",
    am => "Amharic",
    be => "Belarusian",
    bg => "Bulgarian",
    ca => "Catalan; Valencian",
    cs => "Czech",
    da => "Danish",
    de => "German",
    el => "Greek, Modern (1453-)",
    en => "English",
    es => "Spanish",
    et => "Estonian",
    eu => "Basque",
    fi => "Finnish",
    fr => "French",
    he => "Hebrew",
    hr => "Croatian",
    hu => "Hungarian",
    hy => "Armenian",
    is => "Icelandic",
    it => "Italian",
    ja => "Japanese",
    kk => "Kazakh",
    ko => "Korean",
    lt => "Lithuanian",
    nl => "Dutch",
    no => "Norwegian",
    pl => "Polish",
    pt => "Portuguese",
    ro => "Romanian",
    ru => "Russian",
    sk => "Slovak",
    sl => "Slovenian",
    sr => "Serbian",
    sv => "Swedish",
    tr => "Turkish",
    uk => "Ukrainian",
    zh => "Chinese",
    );

1;
